@@ -10,10 +10,6 @@ from .parsers import *
 
 
 class ConditionBase:
-    """Base class for conditions accepted by InterpretCommand. Used to implement custom condition cases. 
-    
-    Subclasses must implement the `test` static method.
-    """
     getter: Callable
     tokens: tuple[str]
     invert: bool
@@ -33,7 +29,6 @@ class ConditionBase:
 
     @staticmethod
     def test(input: Any, *tokens: str) -> bool:
-        """docsdasd"""
         raise NotImplementedError()
     
     @staticmethod
@@ -48,11 +43,9 @@ class InstructionCommand(commands.CommandBase):
     """Base class for Commands accepted by InterpretCommand. Used to implement custom instruction syntax.
     Allows for instruction arguments to be handled earlier, resulting in a more predictable program.
 
-    Requires subclasses to implement `parse_arguments` static method.
+    Requires subclasses to implement `parse_arguments`.
 
     `validate_arguments` is useful for sanity-checking arguments before execution.
-
-    `syntax` is used to generate documentation for the command.
     """
     @staticmethod
     def parse_arguments(args: list[str]) -> list[Any]:
@@ -81,9 +74,6 @@ class InstructionCommand(commands.CommandBase):
 
     @staticmethod
     def syntax() -> str:
-        """Returns a string giving the syntax of the Command, as expected by `parse_arguments`.
-        Note that this string should not include the name you register the command to under the InterpretCommand.
-        """
         raise NotImplementedError()
     
 
